###################################################
### chunk number 1: 
###################################################
options(continue="  ")


###################################################
### chunk number 2: load
###################################################
library(dlnm)
data(chicagoNMMAPS)


###################################################
### chunk number 3: internal.mkbasis
###################################################
basis.var <- mkbasis(1:5, knots=3)
basis.var


###################################################
### chunk number 4: internal.mkbasis2
###################################################
mkbasis(1:5, type="bs", df=4, degree=2)
mkbasis(1:5, type="lin", cenvalue=4)


###################################################
### chunk number 5: internal.mklagbasis
###################################################
mklagbasis(maxlag=5, type="poly", degree=3)


###################################################
### chunk number 6: internal.thr
###################################################
mklagbasis(maxlag=5, type="integer")
mkbasis(1:5, type="dthr", knots=c(2,3))


###################################################
### chunk number 7: internal.int
###################################################
mklagbasis(maxlag=10, type="strata", knots=c(4,7))
mklagbasis(maxlag=10, type="strata", knots=c(4,7), int=F)


###################################################
### chunk number 8: internal.cen
###################################################
mkbasis(0:10, type="poly", degree=3)
mkbasis(0:10, type="poly", degree=3, cen=F)


###################################################
### chunk number 9: example1crossbasis
###################################################
basis.pm <- crossbasis(chicagoNMMAPS$pm10, vartype="lin", lagtype="poly",
	lagdegree=4, cen=F, maxlag=15)
basis.temp <- crossbasis(chicagoNMMAPS$temp, vardf=5, lagtype="strata",
	lagknots=1, cenvalue=21, maxlag=3)


###################################################
### chunk number 10: example1summary
###################################################
summary(basis.pm)


###################################################
### chunk number 11: example1model
###################################################
model <- glm(death ~  basis.pm + basis.temp + ns(time, 7*14) + dow,
	family=quasipoisson(), chicagoNMMAPS)


###################################################
### chunk number 12: example1pred
###################################################
pred.pm <- crosspred(basis.pm, model, at=0:20, cumul=T)


###################################################
### chunk number 13: example1slices
###################################################
crossplot(pred.pm, "slices", var=10,
	title="Effects of a 10-unit increase in PM10 along lags")


###################################################
### chunk number 14: example1slicescumul
###################################################
crossplot(pred.pm, "slices", var=10, cumul=T,
	title="Cumulative effects of a 10-unit increase in PM10 along lags")


###################################################
### chunk number 15: example1slicesnoeval eval=FALSE
###################################################
## crossplot(pred.pm, "slices", var=10,
## 	title="Effects of a 10-unit increase in PM10 along lags")
## crossplot(pred.pm, "slices", var=10, cumul=T,
## 	title="Cumulative effects of a 10-unit increase in PM10 along lags")


###################################################
### chunk number 16: example1effect
###################################################
pred.pm$allRRfit["10"]
cbind(pred.pm$allRRlow, pred.pm$allRRhigh)["10",]


###################################################
### chunk number 17: dataseason
###################################################
chicagoNMMAPSseas <- subset(chicagoNMMAPS, month %in% 6:9)


###################################################
### chunk number 18: example2crossbasis
###################################################
basis.o3 <- crossbasis(chicagoNMMAPSseas$o3, group=chicagoNMMAPSseas$year,
	vartype="hthr", varknots=40.3, lagtype="integer", maxlag=5)
basis.temp <- crossbasis(chicagoNMMAPSseas$temp, group=chicagoNMMAPSseas$year,
	vartype="dthr", varknots=c(15,25), lagtype="strata", lagknots=c(2,6),
	maxlag=10)


###################################################
### chunk number 19: example2modelpred
###################################################
model <- glm(death ~  basis.o3 + basis.temp + ns(doy, 4) + dow,
	family=quasipoisson(), chicagoNMMAPSseas)
pred.o3 <- crosspred(basis.o3, model, at=c(0:65,40.3,50.3))


###################################################
### chunk number 20: example2slices
###################################################
crossplot(pred.o3, "slices", var=50.3, ci="bars",
	title="Effects of a 10-unit increase in ozone along lags")


###################################################
### chunk number 21: example2overall
###################################################
crossplot(pred.o3,"overall",label="Ozone", ylim=c(0.9,1.3),
	title="Overall effects of ozone over 5 days of lag")


###################################################
### chunk number 22: example2noeval1 eval=FALSE
###################################################
## crossplot(pred.o3, "slices", var=50.3, ci="bars",
## 	title="Effects of a 10-unit increase in ozone along lags")
## crossplot(pred.o3,"overall",label="Ozone", ylim=c(0.9,1.3),
## 	title="Overall effects of ozone over 5 days of lag")	


###################################################
### chunk number 23: example2effect
###################################################
pred.o3$allRRfit["50.3"]
cbind(pred.o3$allRRlow, pred.o3$allRRhigh)["50.3",]


###################################################
### chunk number 24: example3crossbasis
###################################################
basis.pm <- crossbasis(chicagoNMMAPS$pm10,vartype="lin", lagtype="strata",
	cen=F, maxlag=1)
basis.temp <- crossbasis(chicagoNMMAPS$temp, vartype="bs", vardf=5, vardegree=2,
	lagdf=5, cenvalue=21, maxlag=30)


###################################################
### chunk number 25: example3noeval eval=FALSE
###################################################
## model <- glm(death ~  basis.pm + basis.temp + ns(time, 7*14) + dow,
## 	family=quasipoisson(), chicagoNMMAPS)
## pred.temp <- crosspred(basis.temp, model, at=-26:33)
## crossplot(pred.temp, label="Temperature",
## 	title="3D graph of temperature effects")
## crossplot(pred.temp, "contour", label="Temperature",
## 	title="Contour graph of temperature effects")


###################################################
### chunk number 26: example3plot3d
###################################################
model <- glm(death ~  basis.pm + basis.temp + ns(time, 7*14) + dow,
	family=quasipoisson(), chicagoNMMAPS)
pred.temp <- crosspred(basis.temp, model, at=-26:33)
crossplot(pred.temp, label="Temperature",
	title="3D graph of temperature effects")


###################################################
### chunk number 27: example3plotcontour
###################################################
crossplot(pred.temp, "contour", label="Temperature",
	title="Contour graph of temperature effects")


###################################################
### chunk number 28: example3overall
###################################################
crossplot(pred.temp, "overall", label="Temperature",
	title="Overall effects of temperature over 30 days of lag")


###################################################
### chunk number 29: example3slices
###################################################
crossplot(pred.temp, "slices", var=c(-20,0,27,33),
	lag=c(0,5,15,28), label="Temperature")


###################################################
### chunk number 30: cleaning
###################################################
unlink("NMMAPS", recursive = TRUE)


